/** ============================================================================
 *  @file   message_os.h
 *
 *  @path   $(DSPLINK)/gpp/src/samples/message_multidsp/Linux/
 *
 *  @desc   OS specific definitions for the message sample.
 *
 *  @ver    1.65.00.03
 *  ============================================================================
 *  Copyright (C) 2002-2009, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


#if !defined (MESSAGE_OS_H)
#define MESSAGE_OS_H

#include <string.h>

#if defined (__cplusplus)
extern "C" {
#endif /* defined (__cplusplus) */


/** ============================================================================
 *  @func   atoi
 *
 *  @desc   Extern declaration for function that converts a string into an
 *          integer value.
 *
 *  @arg    str
 *              String representation of the number.
 *
 *  @ret    <valid integer>
 *              If the 'initial' part of the string represents a valid integer
 *          0
 *              If the string passed does not represent an integer or is NULL.
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
extern int atoi (const char * str) ;


/** ============================================================================
 *  @func   MESSAGEMULTIDSP_Atoi
 *
 *  @desc   This function converts a string into an integer value.
 *
 *  @arg    str
 *              String representation of the number.
 *
 *  @ret    <valid integer>
 *              If the 'initial' part of the string represents a valid integer
 *          0
 *              If the string passed does not represent an integer or is NULL.
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
#define MESSAGEMULTIDSP_Atoi atoi

/** ============================================================================
 *  @func   MESSAGEMULTIDSP_Atoi
 *
 *  @desc   This function converts a string into an integer value.
 *
 *  @arg    str
 *              String representation of the number.
 *
 *  @ret    <valid integer>
 *              If the 'initial' part of the string represents a valid integer
 *          0
 *              If the string passed does not represent an integer or is NULL.
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
#define MESSAGEMULTIDSP_Atoi atoi


/** ============================================================================
 *  @func   MESSAGEMULTIDSP_Strcat
 *
 *  @desc   This function concatenates two strings.
 *
 *  @arg    dest
 *              Destination string.
 *  @arg    src
 *              Source string to be appended to the destination string.
 *
 *  @ret    Pointer to the resulting string.
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
#define MESSAGEMULTIDSP_Strcat strcat


/** ============================================================================
 *  @func   MESSAGEMULTIDSP_Strcpy
 *
 *  @desc   This function copies source string to destination string
 *
 *  @arg    dest
 *              Destination string.
 *  @arg    src
 *              Source string.
 *
 *  @ret    None
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
#define MESSAGEMULTIDSP_Strcpy strcpy

/** ============================================================================
 *  @func   MESSAGEMULTIDSP_2Print
 *
 *  @desc   Print a message with two arguments.
 *
 *  @modif  None
 *  ============================================================================
 */
NORMAL_API
Void
MESSAGEMULTIDSP_2Print (Char8 * str, Uint32 arg, Uint32 arg1) ;


#if defined (MESSAGE_PROFILE)
/** ============================================================================
 *  @func   MESSAGE_GetStartTime ()
 *
 *  @desc   This function records the start time in microseconds.
 *
 *  @arg    None.
 *
 *  @ret    None.
 *
 *  @enter  None.
 *
 *  @leave  None.
 *
 *  @see    None.
 *  ============================================================================
 */
EXPORT_API
Void
MESSAGEMULTIDSP_GetStartTime (Void) ;


/** ============================================================================
 *  @func   MESSAGE_GetEndTime ()
 *
 *  @desc   This function records the end time in microseconds.
 *
 *  @arg    None.
 *
 *  @ret    None.
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
EXPORT_API
Void
MESSAGEMULTIDSP_GetEndTime (Void) ;


/** ============================================================================
 *  @func   MESSAGE_GetProfileInfo
 *
 *  @desc   It converts a time variable to elapsed time structure.
 *
 *  @arg    numIterations
 *             Number of iteratiosn for which message sample is excuted.
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
EXPORT_API
Void
MESSAGEMULTIDSP_GetProfileInfo (Uint32 numIterations) ;

#endif /* if defined (MESSAGE_PROFILE) */

#if defined (__cplusplus)
}
#endif /* defined (__cplusplus) */


#endif /* !defined (MESSAGE_OS_H) */
